"""
/***************************************************************************
      zoomtopasteDialog  - A QGIS plugin to zoom the map canvas to a point
                         specified in the clippboard
                             -------------------
    begin                : 2014-10-14
    copyright            : (C) 2014 by GD
    email                : gd at geoplaning.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
"""
# Import the PyQt and QGIS libraries
from PyQt4.QtCore import *
from PyQt4.QtGui import *
from qgis.core import *
from qgis.gui import *
# Initialize Qt resources from file resources.py
# Import the code for the dialog
from zoomtopastedialog import zoomtopasteDialog


class zoomtopaste:
    def __init__(self, iface):
        # Save reference to the QGIS interface
        self.iface = iface

    def initGui(self):
        # Create action that will start plugin configuration
        self.action = QAction(QIcon(":/plugins/zoomtopaste/icon.png"), "Zoom To Paste", self.iface.mainWindow())
        self.action.setWhatsThis("Configuration for Zoom To Paste plugin")
        # connect the action to the run method
        QObject.connect(self.action, SIGNAL("activated()"), self.run)
        # self.iface.setAcceptDrops(True)
        # Add toolbar button and menu item
        self.iface.addToolBarIcon(self.action)
        self.iface.addPluginToMenu("&Zoom to Paste...", self.action)

        #How to call a method by a key shortcut
        self.keyAction = QAction("Zoom to Paste", self.iface.mainWindow())
        self.iface.registerMainWindowAction(self.keyAction, "F7")

        # action1 is triggered by the F7 key
        self.iface.addPluginToMenu("&Zoom to Paste", self.keyAction)
        QObject.connect(self.keyAction, SIGNAL("triggered()"), self.keyActionF7)


        #How to call a method by a key shortcut
        self.keyAction = QAction("Select Database", self.iface.mainWindow())
        self.iface.registerMainWindowAction(self.keyAction, "F8")

        #action1 is triggered by the F8 key
        self.iface.addPluginToMenu("&Select Database", self.keyAction)
        QObject.connect(self.keyAction, SIGNAL("triggered()"), self.keyActionF8)
        
        
        
    def unload(self):
        # Remove the plugin menu item and icon
        self.iface.removePluginMenu("&Zoom to Paste...", self.action)
        self.iface.removeToolBarIcon(self.action)

    # run method that performs all the real work
    def run(self):
        # create and show the zoomtopaste dialog
        dlg = zoomtopasteDialog()
        # dlg.setupUi(self)
        # fetch the last used values from settings and intialize the
        # dialog with them
        settings = QSettings("MicroResources", "zoomtopaste")

        xValue = settings.value("coordinate/x", '')
        dlg.ui.xCoord.setText(str(xValue))
        
        yValue = settings.value("coordinate/y", '')
        dlg.ui.yCoord.setText(str(yValue))
        
        scale = settings.value("zoom/scale", 4)
        dlg.ui.spinBoxScale.setValue(int(scale))
        
        #cbx = settings.value("zoom/checked", 0)
        #dlg.ui.checkBox.setChecked(int(cbx))
        
        
        dlg.show()
        result = dlg.exec_()
        # See if OK was pressed
        if result == 1:
            # Get the coordinates and scale factor from the dialog
            x = dlg.ui.xCoord.text()
            y = dlg.ui.yCoord.text()
            scale = dlg.ui.spinBoxScale.value()


            rect = QgsRectangle(float(x) - scale,float(y) - scale,float(x) + scale,float(y) + scale)
            # Get the map canvas
            mc = self.iface.mapCanvas()
            # Set the extent to our new rectangle
            mc.setExtent(rect)
            # Refresh the map
            mc.refresh()


            # store the settings
            settings.setValue("coordinate/x", x)
            settings.setValue("coordinate/y", y)
            settings.setValue("zoom/scale", scale)

            settings.setValue("zoom/checked", "1" if dlg.ui.checkBox.isChecked() else "0")
        
            if dlg.ui.checkBox.isChecked():
                QObject.connect(QApplication.clipboard(), SIGNAL("dataChanged()"), self.dropChangedGo)
            else:    
                QObject.connect(QApplication.clipboard(), SIGNAL("dataChanged()"), self.destroy)
            

    def dropChangedGo(self):
        
        dlg = zoomtopasteDialog()
                
        if dlg.ui.checkBox.isChecked:
            clipboard = QApplication.clipboard()
            text = unicode(clipboard.text())
    
            # create and show the zoomtopaste dialog
    
            if text != "" and text.find(',')>0:
                
                str = text.split(",")
                x = str[1]
                y = str[0]
                
                if x > 0 and y > 0:
        
                    dlg.ui.xCoord.setText((x))
                    dlg.ui.yCoord.setText((y))
                    
                    scale = dlg.ui.spinBoxScale.value()
                    
                    # Create a rectangle to cover the new extent
                    rect = QgsRectangle(float(x) - scale, float(y) - scale, float(x) + scale, float(y) + scale)
                    # Get the map canvas
                    mc = self.iface.mapCanvas()
                    # Set the extent to our new rectangle
                    mc.setExtent(rect)
                    # Refresh the map
                    mc.refresh()
                    
                    settings = QSettings("MicroResources", "zoomtopaste")
                    settings.setValue("coordinate/x", x)
                    settings.setValue("coordinate/y", y)
                    settings.setValue("zoom/scale", scale)
            else:
                QMessageBox.information(self.iface.mainWindow(), "Im Clipbord sind falsche Daten", text)
       
             
                  
    def keyActionF7(self):

        
        dlg = zoomtopasteDialog()       
         
        clipboard = QApplication.clipboard()
        text = unicode(clipboard.text())

        # create and show the zoomtopaste dialog

        if text != "" and text.find(',')>0:
            
            str = text.split(",")
            x = str[1]
            y = str[0]
            
            if x > 0 and y > 0:
                
                dlg.ui.xCoord.setText((x))
                dlg.ui.yCoord.setText((y))
                
                scale = dlg.ui.spinBoxScale.value()
                
                # Create a rectangle to cover the new extent
                rect = QgsRectangle(float(x) - scale, float(y) - scale, float(x) + scale, float(y) + scale)
                # Get the map canvas
                mc = self.iface.mapCanvas()
                # Set the extent to our new rectangle
                mc.setExtent(rect)
                # Refresh the map
                mc.refresh()
                
                settings = QSettings("MicroResources", "zoomtopaste")
                settings.setValue("coordinate/x", x)
                settings.setValue("coordinate/y", y)
                settings.setValue("zoom/scale", scale)
        else:
            QMessageBox.information(self.iface.mainWindow(), "Im Clipbord sind falsche Daten", text)


    def Zoom(self):
        
        clipboard = QApplication.clipboard()
        text = unicode(clipboard.text())

        # create and show the zoomtopaste dialog

        if text != "" and text.find(',')>0:
            
            str = text.split(",")
            x = str[1]
            y = str[0]
            
            if x > 0 and y > 0:
                dlg = zoomtopasteDialog()
                dlg.ui.xCoord.setText((x))
                dlg.ui.yCoord.setText((y))
                
                scale = dlg.ui.spinBoxScale.value()
                
                # Create a rectangle to cover the new extent
                rect = QgsRectangle(float(x) - scale, float(y) - scale, float(x) + scale, float(y) + scale)
                # Get the map canvas
                mc = self.iface.mapCanvas()
                # Set the extent to our new rectangle
                mc.setExtent(rect)
                # Refresh the map
                mc.refresh()
                
                settings = QSettings("MicroResources", "zoomtopaste")
                settings.setValue("coordinate/x", x)
                settings.setValue("coordinate/y", y)
                settings.setValue("zoom/scale", scale)
        else:
            QMessageBox.information(self.iface.mainWindow(), "Im Clipbord sind falsche Daten", text)


    def keyActionF8(self):
        QMessageBox.information(self.iface.mainWindow(), "Info", "in selectFeature function")
        # setup the provider select to filter results based on a rectangle
        pntGeom = QgsGeometry.fromPoint(point)
        # scale-dependent buffer of 2 pixels-worth of map units
        pntBuff = pntGeom.buffer((self.canvas.mapUnitsPerPixel() * 2), 0)
        rect = pntBuff.boundingBox()
        # get currentLayer and dataProvider
        cLayer = self.canvas.currentLayer()
        selectList = []
        if cLayer:
            provider = cLayer.dataProvider()
            feat = QgsFeature()
            # create the select statement
            provider.select([],
                              rect)  # the arguments mean no attributes returned, and do a bbox filter with our buffered rectangle to limit the amount of features
            while provider.nextFeature(feat):
                # if the feat geom returned from the selection intersects our point then put it in a list
                if feat.geometry().intersects(pntGeom):
                    selectList.append(feat.id())

            # make the actual selection
            cLayer.setSelectedFeatures(selectList)
        else:
            QMessageBox.information(self.iface.mainWindow(), "Info", "No layer currently selected in TOC")
            
            
    def destroy(self):
        pass
